@@ -150,7 +150,7 @@ class OptionConstantsTest(unittest.TestCase):
         curl.close()
 
     @util.min_libcurl(7, 22, 0)
-    @pytest.mark.gssapi
+    @util.only_gssapi
     def test_gssapi_delegation_options(self):
         curl = pycurl.Curl()
         curl.setopt(curl.GSSAPI_DELEGATION, curl.GSSAPI_DELEGATION_FLAG)
@@ -456,10 +456,9 @@ class OptionConstantsTest(unittest.TestCase):
         curl.setopt(curl.PROXY_SSL_OPTIONS, curl.SSLOPT_NO_REVOKE)
         curl.close()
 
-    # Apparently TLSAUTH_TYPE=SRP is an unknown option on appveyor
-    @util.only_unix
     @util.min_libcurl(7, 52, 0)
-    @util.only_ssl_backends('openssl', 'gnutls', 'schannel')
+    @util.only_ssl_backends('openssl', 'gnutls')
+    @util.only_tls_srp
     def test_proxy_tlsauth(self):
         curl = pycurl.Curl()
         curl.setopt(curl.PROXY_TLSAUTH_USERNAME, "test")
@@ -542,14 +541,14 @@ class OptionConstantsTest(unittest.TestCase):
         curl.close()
 
     @util.min_libcurl(7, 61, 0)
-    @util.only_ssl_backends('openssl', 'schannel')
+    @util.only_ssl_backends('openssl')
     def test_tls13_ciphers(self):
         curl = pycurl.Curl()
         curl.setopt(curl.TLS13_CIPHERS, 'TLS_CHACHA20_POLY1305_SHA256')
         curl.close()
 
     @util.min_libcurl(7, 61, 0)
-    @util.only_ssl_backends('openssl', 'schannel')
+    @util.only_ssl_backends('openssl')
     def test_proxy_tls13_ciphers(self):
         curl = pycurl.Curl()
         curl.setopt(curl.PROXY_TLS13_CIPHERS, 'TLS_CHACHA20_POLY1305_SHA256')
@@ -691,10 +690,9 @@ class OptionConstantsSettingTest(unittest.TestCase):
         assert self.curl.PROTO_SMB is not None
         assert self.curl.PROTO_SMBS is not None
 
-    # Apparently TLSAUTH_TYPE=SRP is an unknown option on appveyor
-    @util.only_unix
     @util.min_libcurl(7, 21, 4)
-    @util.only_ssl_backends('openssl', 'gnutls', 'schannel')
+    @util.only_ssl_backends('openssl', 'gnutls')
+    @util.only_tls_srp
     def test_tlsauth(self):
         self.curl.setopt(self.curl.TLSAUTH_TYPE, "SRP")
         self.curl.setopt(self.curl.TLSAUTH_USERNAME, "test")
